/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.datasource.plugin.ftp;

import org.apache.seatunnel.api.configuration.Option;
import org.apache.seatunnel.api.configuration.Options;
import org.apache.seatunnel.api.configuration.util.OptionRule;

public class FtpOptionRule {

    public static final Option<String> HOST =
            Options.key("host")
                    .stringType()
                    .noDefaultValue()
                    .withDescription("the default host to use for connections");

    public static final Option<Integer> PORT =
            Options.key("port")
                    .intType()
                    .noDefaultValue()
                    .withDescription("the default port to use for connections");
    public static final Option<String> USER =
            Options.key("user")
                    .stringType()
                    .noDefaultValue()
                    .withDescription("the AMQP user name to use when connecting to the broker");

    public static final Option<String> PASSWORD =
            Options.key("password")
                    .stringType()
                    .noDefaultValue()
                    .withDescription("the password to use when connecting to the broker");
    public static final Option<String> PATH =
            Options.key("path").stringType().noDefaultValue().withDescription("path");
    public static final Option<FileFormat> FILE_FORMAT_TYPE =
            Options.key("file_format_type")
                    .enumType(FileFormat.class)
                    .noDefaultValue()
                    .withDescription("file_format_type");

    public static final Option<String> DELIMITER =
            Options.key("delimiter").stringType().noDefaultValue().withDescription("delimiter");

    public static OptionRule optionRule() {
        return OptionRule.builder().required(HOST, PORT).optional(USER, PASSWORD, PATH).build();
    }

    public static OptionRule metadataRule() {
        return OptionRule.builder().required(FILE_FORMAT_TYPE).build();
    }

    public enum FileFormat {
        CSV("csv"),
        TEXT("text"),
        PARQUET("parquet"),
        ORC("orc"),
        JSON("json"),
        EXCEL("excel");

        private final String type;

        FileFormat(String type) {
            this.type = type;
        }
    }
}
