/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.datasource.plugin.influxdb;

import org.apache.seatunnel.api.configuration.Option;
import org.apache.seatunnel.api.configuration.Options;
import org.apache.seatunnel.api.configuration.util.OptionRule;

import java.util.List;

public class InfluxdbOptionRule {

    public static final Option<List<String>> URL =
            Options.key("url")
                    .listType()
                    .noDefaultValue()
                    .withDescription(
                            "Influxdb Url address, the format is http://host:port, allowing only hosts to be specified. Such as http://192.168.1.124:8086 ");

    public static final Option<String> TOKEN =
            Options.key("token").stringType().noDefaultValue().withDescription("Influxdb token ");

    public static final Option<String> BUCKET =
            Options.key("bucket").stringType().noDefaultValue().withDescription("Influxdb bucket");

    public static final Option<String> ORG =
            Options.key("org").stringType().noDefaultValue().withDescription("Influxdb org");

    public static final Option<String> HOUR =
            Options.key("hour")
                    .stringType()
                    .noDefaultValue()
                    .withDescription("Influxdb hour(Unit: Hour, negative)");

    public static OptionRule optionRule() {
        return OptionRule.builder().required(URL).optional(TOKEN, BUCKET, ORG, HOUR).build();
    }

    public static OptionRule metadataRule() {
        return OptionRule.builder().required(TOKEN).build();
    }
}
