/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.datasource.plugin.opcua;

import org.apache.seatunnel.api.configuration.Option;
import org.apache.seatunnel.api.configuration.Options;
import org.apache.seatunnel.api.configuration.util.OptionRule;

public class OpcuaOptionRule {

    public static final Option<String> HOST =
            Options.key("host").stringType().noDefaultValue().withDescription("socket host");

    public static final Option<Integer> PORT =
            Options.key("port").intType().noDefaultValue().withDescription("socket port");

    public static final Option<String> SUFFIX =
            Options.key("suffix").stringType().noDefaultValue().withDescription("suffix");

    public static final Option<Integer> NS =
            Options.key("ns").intType().noDefaultValue().withDescription("ns");

    public static final Option<String> ID =
            Options.key("id").stringType().noDefaultValue().withDescription("id");

    public static final Option<String> TYPE =
            Options.key("type").stringType().defaultValue("int").withDescription("type");

    public static final Option<Integer> GS =
            Options.key("gs").intType().defaultValue(1).withDescription("type");

    public static OptionRule optionRule() {
        return OptionRule.builder().required(HOST, PORT, SUFFIX, NS, ID, TYPE).optional(GS).build();
    }

    public static OptionRule metadataRule() {
        return OptionRule.builder().required(NS, ID, TYPE).build();
    }
}
