/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.datasource.plugin.opcua;

import org.apache.seatunnel.shade.com.typesafe.config.Config;
import org.apache.seatunnel.shade.com.typesafe.config.ConfigFactory;

import java.util.Map;
import java.util.Properties;

import static com.google.common.base.Preconditions.checkArgument;

public class OpcuaRequestParamsUtils {

    public static Properties parsePropertiesFromRequestParams(Map<String, String> requestParams) {
        checkArgument(
                requestParams.containsKey(OpcuaOptionRule.HOST.key()),
                String.format("Missing %s in requestParams", OpcuaOptionRule.HOST.key()));
        final Properties properties = new Properties();
        properties.put(OpcuaOptionRule.HOST.key(), requestParams.get(OpcuaOptionRule.HOST.key()));
        if (requestParams.containsKey(OpcuaOptionRule.PORT.key())) {
            Config configObject =
                    ConfigFactory.parseString(requestParams.get(OpcuaOptionRule.PORT.key()));
            configObject
                    .entrySet()
                    .forEach(
                            entry -> {
                                properties.put(
                                        entry.getKey(), entry.getValue().unwrapped().toString());
                            });
        }
        return properties;
    }
}
