/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.app.controller;

import org.apache.seatunnel.app.common.Result;
import org.apache.seatunnel.app.service.IRoleService;

import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

import javax.annotation.Resource;
import javax.validation.constraints.NotNull;

@RequestMapping("/seatunnel/api/v1/auth")
@RestController
public class AuthController {

    @Resource private IRoleService roleServiceImpl;

    @GetMapping("/userRole")
    @ApiOperation(value = "check relation between user and role", httpMethod = "GET")
    @ApiImplicitParams({
        @ApiImplicitParam(name = "username", value = "user name", dataType = "String"),
        @ApiImplicitParam(name = "roleName", value = "role name", dataType = "String"),
    })
    public Result<Boolean> userRole(
            @RequestParam("username") @NotNull String username,
            @RequestParam("roleName") @NotNull String roleName) {
        final boolean b = roleServiceImpl.checkUserRole(username, roleName);
        return Result.success(b);
    }
}
