/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.app.thirdparty.datasource;

import org.apache.seatunnel.shade.com.typesafe.config.Config;

import org.apache.seatunnel.api.configuration.util.OptionRule;
import org.apache.seatunnel.app.domain.request.connector.BusinessMode;
import org.apache.seatunnel.app.domain.request.job.DataSourceOption;
import org.apache.seatunnel.app.domain.request.job.SelectTableFields;
import org.apache.seatunnel.app.domain.response.datasource.VirtualTableDetailRes;
import org.apache.seatunnel.app.dynamicforms.FormStructure;
import org.apache.seatunnel.common.constants.PluginType;

import java.util.List;

public interface DataSourceConfigSwitcher {

    /**
     * OptionRule OptionRule
     *
     * @param connectorName connectorName
     * @param dataSourceOptionRule OptionRule
     * @param virtualTableOptionRule OptionRule
     * @param businessMode businessMode
     * @param pluginType Source or Sink
     * @param connectorOptionRule OptionRule
     * @param excludedKeys excludedKeys
     * @return form
     */
    FormStructure filterOptionRule(
            String connectorName,
            OptionRule dataSourceOptionRule,
            OptionRule virtualTableOptionRule,
            BusinessMode businessMode,
            PluginType pluginType,
            OptionRule connectorOptionRule,
            List<String> excludedKeys);

    /**
     * mergeDatasourceConfig
     *
     * @param dataSourceInstanceConfig dataSourceInstanceConfig
     * @param virtualTableDetail virtualTableDetail
     * @param dataSourceOption dataSourceOption
     * @param selectTableFields selectTableFields
     * @param businessMode businessMode
     * @param pluginType source or sink
     * @param connectorConfig connectorConfig
     * @return config
     */
    Config mergeDatasourceConfig(
            Config dataSourceInstanceConfig,
            VirtualTableDetailRes virtualTableDetail,
            DataSourceOption dataSourceOption,
            SelectTableFields selectTableFields,
            BusinessMode businessMode,
            PluginType pluginType,
            Config connectorConfig);
}
